@@ -28,13 +28,7 @@
 #include <gdk/gdkkeysyms.h>
 
 #include <gdk/gdk.h>
-
-#ifdef GDK_WINDOWING_X11
 #include <gdk/gdkx.h>
-#ifndef GDK_IS_X11_DISPLAY
-#define GDK_IS_X11_DISPLAY(display) 1
-#endif
-#endif
 
 #include "terminal-accels.h"
 #include "terminal-app.h"
@@ -49,11 +43,6 @@
 
 #include "eggshell.h"
 
-#if GTK_CHECK_VERSION(3, 0, 0)
- #include <gdk/gdkkeysyms-compat.h>
- #define GDK_WINDOW_XWINDOW GDK_WINDOW_XID
-#endif
-
 #define URL_MATCH_CURSOR  (GDK_HAND2)
 #define SKEY_MATCH_CURSOR (GDK_HAND2)
 
@@ -149,7 +138,7 @@ static char* terminal_screen_check_match       (TerminalScreen            *scree
         int                   row,
         int                  *flavor);
 
-static guint signals[LAST_SIGNAL];
+static guint signals[LAST_SIGNAL] = { 0 };
 
 #define USERCHARS "-[:alnum:]"
 #define USERCHARS_CLASS "[" USERCHARS "]"
@@ -158,7 +147,7 @@ static guint signals[LAST_SIGNAL];
 #define HOST HOSTCHARS_CLASS "+(\\." HOSTCHARS_CLASS "+)*"
 #define PORT "(?:\\:[[:digit:]]{1,5})?"
 #define PATHCHARS_CLASS "[-[:alnum:]\\Q_$.+!*,:;@&=?/~#%\\E]"
-#define PATHTERM_CLASS "[^\\Q]'.}>) \t\r\n,\"\\E]"
+#define PATHTERM_CLASS "[^\\Q]'.:}>) \t\r\n,\"\\E]"
 #define SCHEME "(?:news:|telnet:|nntp:|file:\\/|https?:|ftps?:|sftp:|webcal:)"
 #define USERPASS USERCHARS_CLASS "+(?:" PASSCHARS_CLASS "+)?"
 #define URLPATH   "(?:(/"PATHCHARS_CLASS"+(?:[(]"PATHCHARS_CLASS"*[)])*"PATHCHARS_CLASS"*)*"PATHTERM_CLASS")?"
@@ -277,9 +266,9 @@ terminal_screen_class_enable_menu_bar_accel_notify_cb (TerminalApp *app,
 
 	binding_set = gtk_binding_set_by_class (klass);
 	if (enable)
-		gtk_binding_entry_remove (binding_set, GDK_F10, GDK_SHIFT_MASK);
+		gtk_binding_entry_remove (binding_set, GDK_KEY_F10, GDK_SHIFT_MASK);
 	else
-		gtk_binding_entry_skip (binding_set, GDK_F10, GDK_SHIFT_MASK);
+		gtk_binding_entry_skip (binding_set, GDK_KEY_F10, GDK_SHIFT_MASK);
 }
 
 static TerminalWindow *
@@ -944,6 +933,11 @@ terminal_screen_profile_notify_cb (TerminalProfile *profile,
 		 * update_on_realize
 		 */
 		terminal_window_update_geometry (window);
+
+		/* madars.vitolins@gmail.com 24/07/2014 -
+		 * update terminal window config
+		 * with the flag of copy selection to cliboard or not. */
+		terminal_window_update_copy_selection(screen, window);
 	}
 
 	if (!prop_name || prop_name == I_(TERMINAL_PROFILE_SCROLLBAR_POSITION))
@@ -1409,14 +1403,9 @@ get_child_environment (TerminalScreen *screen,
 	g_hash_table_replace (env_table, g_strdup ("COLORTERM"), g_strdup (EXECUTABLE_NAME));
 	g_hash_table_replace (env_table, g_strdup ("TERM"), g_strdup ("xterm")); /* FIXME configurable later? */
 
-#ifdef GDK_WINDOWING_X11
 	/* FIXME: moving the tab between windows, or the window between displays will make the next two invalid... */
-	if (GDK_IS_X11_DISPLAY(display))
-	{
-		g_hash_table_replace (env_table, g_strdup ("WINDOWID"), g_strdup_printf ("%ld", GDK_WINDOW_XWINDOW (gtk_widget_get_window (window))));
-		g_hash_table_replace (env_table, g_strdup ("DISPLAY"), g_strdup (gdk_display_get_name (display)));
-	}
-#endif
+	g_hash_table_replace (env_table, g_strdup ("WINDOWID"), g_strdup_printf ("%ld", GDK_WINDOW_XID (gtk_widget_get_window (window))));
+	g_hash_table_replace (env_table, g_strdup ("DISPLAY"), g_strdup (gdk_display_get_name (display)));
 
 	list_schemas = g_settings_list_schemas();
 	schema_exists = FALSE;
